@@ -1,17 +1,18 @@
 """
 Main interface for the velbusaio lib
 """
+from __future__ import annotations
 
 import asyncio
 import logging
 import pickle
 import ssl
-from typing import Union
 
 import serial
 import serial_asyncio
 
 from velbusaio.const import LOAD_TIMEOUT
+from velbusaio.exceptions import VelbusConnectionFailed, VelbusConnectionTerminated
 from velbusaio.handler import PacketHandler
 from velbusaio.helpers import get_cache_dir
 from velbusaio.messages.module_type_request import ModuleTypeRequestMessage
@@ -27,9 +28,8 @@ class Velbus:
     A velbus controller
     """
 
-    def __init__(self, dsn) -> None:
+    def __init__(self, dsn, cache_dir=get_cache_dir()) -> None:
         self._log = logging.getLogger("velbus")
-        self._log.setLevel(logging.DEBUG)
         self._dsn = dsn
         self._parser = VelbusParser()
         self._handler = PacketHandler(self.send, self)
@@ -39,6 +39,7 @@ class Velbus:
         self._submodules = []
         self._send_queue = asyncio.Queue()
         self._tasks = []
+        self._cache_dir = cache_dir
 
     async def add_module(
         self,
@@ -51,12 +52,14 @@ class Velbus:
         build_week=None,
     ) -> None:
         """
-        Add a founc module to the module cache
+        Add a found module to the module cache
         """
-        mod = self._load_module_from_cache(addr)
-        if mod:
+        mod = self._load_module_from_cache(self._cache_dir, addr)
+        if mod is not None:
             self._log.info(f"Load module from CACHE: {addr}")
             self._modules[addr] = mod
+            self._modules[addr].initialize(self.send)
+            await self._modules[addr].load(True)
         else:
             self._log.info(f"Load NEW module: {typ} @ {addr}")
             self._modules[addr] = Module(
@@ -67,9 +70,10 @@ class Velbus:
                 build_year=build_year,
                 build_week=build_week,
                 memorymap=memorymap,
+                cache_dir=self._cache_dir,
             )
-        self._modules[addr].initialize(self.send)
-        await self._modules[addr].load()
+            self._modules[addr].initialize(self.send)
+            await self._modules[addr].load()
 
     async def add_submodules(self, addr, subList) -> None:
         for sub_num, sub_addr in subList.items():
@@ -80,9 +84,9 @@ class Velbus:
             self._modules[sub_addr] = self._modules[addr]
         self._modules[addr].cleanupSubChannels()
 
-    def _load_module_from_cache(self, address) -> Union[None, str]:
+    def _load_module_from_cache(self, cache_dir, address) -> None | str:
         try:
-            with open(f"{get_cache_dir()}/{address}.p", "rb") as fl:
+            with open(f"{cache_dir}/{address}.p", "rb") as fl:
                 return pickle.load(fl)
         except OSError:
             pass
@@ -93,7 +97,7 @@ class Velbus:
         """
         return self._modules
 
-    def get_module(self, addr: str) -> Union[None, Module]:
+    def get_module(self, addr: str) -> None | Module:
         """
         Get a module on an address
         """
@@ -101,7 +105,7 @@ class Velbus:
             return self._modules[addr]
         return None
 
-    def get_channels(self, addr: str) -> Union[None, dict]:
+    def get_channels(self, addr: str) -> None | dict:
         """
         Get the channels for an address
         """
@@ -128,20 +132,29 @@ class Velbus:
             else:
                 tmp = self._dsn.split(":")
                 ctx = None
-            self._reader, self._writer = await asyncio.open_connection(
-                tmp[0], tmp[1], ssl=ctx
-            )
+            try:
+                self._reader, self._writer = await asyncio.open_connection(
+                    tmp[0], tmp[1], ssl=ctx
+                )
+            except ConnectionRefusedError as err:
+                raise VelbusConnectionFailed() from err
         else:
             # serial port
-            self._reader, self._writer = await serial_asyncio.open_serial_connection(
-                url=self._dsn,
-                baudrate=38400,
-                bytesize=serial.EIGHTBITS,
-                parity=serial.PARITY_NONE,
-                stopbits=serial.STOPBITS_ONE,
-                xonxoff=0,
-                rtscts=1,
-            )
+            try:
+                (
+                    self._reader,
+                    self._writer,
+                ) = await serial_asyncio.open_serial_connection(
+                    url=self._dsn,
+                    baudrate=38400,
+                    bytesize=serial.EIGHTBITS,
+                    parity=serial.PARITY_NONE,
+                    stopbits=serial.STOPBITS_ONE,
+                    xonxoff=0,
+                    rtscts=1,
+                )
+            except FileNotFoundError as err:
+                raise VelbusConnectionFailed() from err
         if test_connect:
             return
         # create reader, parser and writer tasks
@@ -170,7 +183,7 @@ class Velbus:
             await asyncio.wait_for(tsk, timeout=timeout)
         except asyncio.TimeoutError:
             self._log.error(
-                f"Not all modules are laoded within a timeout of {LOAD_TIMEOUT} seconds, continuing with the loaded modules"
+                f"Not all modules are loaded within a timeout of {LOAD_TIMEOUT} seconds, continuing with the loaded modules"
             )
 
     async def _check_if_modules_are_loaded(self) -> None:
@@ -202,7 +215,10 @@ class Velbus:
             msg = await self._send_queue.get()
             self._log.debug(f"SENDING message: {msg}")
             # print(':'.join('{:02X}'.format(x) for x in msg.to_binary()))
-            self._writer.write(msg.to_binary())
+            try:
+                self._writer.write(msg.to_binary())
+            except Exception:
+                raise VelbusConnectionTerminated()
             await asyncio.sleep(0.11)
 
     async def _socket_read_task(self) -> None:
@@ -210,7 +226,10 @@ class Velbus:
         Task to read from a socket and push into a queue
         """
         while True:
-            data = await self._reader.read(10)
+            try:
+                data = await self._reader.read(10)
+            except Exception:
+                raise VelbusConnectionTerminated()
             self._parser.feed(data)
 
     async def _parser_task(self) -> None:
